@@ -13,7 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import ConfigParser
+import os
+
+try:
+    import ConfigParser
+except ImportError:
+    import configparser as ConfigParser
 
 from raxmon_cli.constants import CONFIG_PATH
 
@@ -63,22 +68,30 @@ def instance_to_dict(instance, keys, include_none=False):
 
 
 def get_credentials():
+    username = os.getenv('USERNAME', None)
+    api_key = os.getenv('API_KEY', None)
+    api_url = os.getenv('API_URL', None)
+
     config = ConfigParser.ConfigParser()
     config.read(CONFIG_PATH)
 
-    try:
-        username = config.get('credentials', 'username', None)
-    except ConfigParser.Error:
-        username = None
+    if not username:
+      try:
+          username = config.get('credentials', 'username')
+      except ConfigParser.Error:
+          username = None
 
-    try:
-        api_key = config.get('credentials', 'api_key', None)
-    except ConfigParser.Error:
-        api_key = None
+    if not api_key:
+      try:
+          api_key = config.get('credentials', 'api_key')
+      except ConfigParser.Error:
+          api_key = None
 
-    try:
-        api_url = config.get('api', 'url', None)
-    except ConfigParser.Error:
-        api_url = None
+
+    if not api_url:
+      try:
+          api_url = config.get('api', 'url')
+      except ConfigParser.Error:
+          api_url = None
 
     return (username, api_key, api_url)
